from enum import Enum
import math
import string


class WarpingMomentOfInertiaUnits(Enum):
        """
            WarpingMomentOfInertiaUnits enumeration
        """
        
        MeterToTheSixth = 'meter_to_the_sixth'
        """
            
        """
        
        DecimeterToTheSixth = 'decimeter_to_the_sixth'
        """
            
        """
        
        CentimeterToTheSixth = 'centimeter_to_the_sixth'
        """
            
        """
        
        MillimeterToTheSixth = 'millimeter_to_the_sixth'
        """
            
        """
        
        FootToTheSixth = 'foot_to_the_sixth'
        """
            
        """
        
        InchToTheSixth = 'inch_to_the_sixth'
        """
            
        """
        

class WarpingMomentOfInertia:
    """
    A geometric property of an area that is used to determine the warping stress.

    Args:
        value (float): The value.
        from_unit (WarpingMomentOfInertiaUnits): The WarpingMomentOfInertia unit to create from, The default unit is MeterToTheSixth
    """
    def __init__(self, value: float, from_unit: WarpingMomentOfInertiaUnits = WarpingMomentOfInertiaUnits.MeterToTheSixth):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__meters_to_the_sixth = None
        
        self.__decimeters_to_the_sixth = None
        
        self.__centimeters_to_the_sixth = None
        
        self.__millimeters_to_the_sixth = None
        
        self.__feet_to_the_sixth = None
        
        self.__inches_to_the_sixth = None
        

    def __convert_from_base(self, from_unit: WarpingMomentOfInertiaUnits) -> float:
        value = self.__value
        
        if from_unit == WarpingMomentOfInertiaUnits.MeterToTheSixth:
            return (value)
        
        if from_unit == WarpingMomentOfInertiaUnits.DecimeterToTheSixth:
            return (value * 1e6)
        
        if from_unit == WarpingMomentOfInertiaUnits.CentimeterToTheSixth:
            return (value * 1e12)
        
        if from_unit == WarpingMomentOfInertiaUnits.MillimeterToTheSixth:
            return (value * 1e18)
        
        if from_unit == WarpingMomentOfInertiaUnits.FootToTheSixth:
            return (value / math.pow(0.3048, 6))
        
        if from_unit == WarpingMomentOfInertiaUnits.InchToTheSixth:
            return (value / math.pow(2.54e-2, 6))
        
        return None


    def __convert_to_base(self, value: float, to_unit: WarpingMomentOfInertiaUnits) -> float:
        
        if to_unit == WarpingMomentOfInertiaUnits.MeterToTheSixth:
            return (value)
        
        if to_unit == WarpingMomentOfInertiaUnits.DecimeterToTheSixth:
            return (value / 1e6)
        
        if to_unit == WarpingMomentOfInertiaUnits.CentimeterToTheSixth:
            return (value / 1e12)
        
        if to_unit == WarpingMomentOfInertiaUnits.MillimeterToTheSixth:
            return (value / 1e18)
        
        if to_unit == WarpingMomentOfInertiaUnits.FootToTheSixth:
            return (value * math.pow(0.3048, 6))
        
        if to_unit == WarpingMomentOfInertiaUnits.InchToTheSixth:
            return (value * math.pow(2.54e-2, 6))
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_meters_to_the_sixth(meters_to_the_sixth: float):
        """
        Create a new instance of WarpingMomentOfInertia from a value in meters_to_the_sixth.

        

        :param meters: The WarpingMomentOfInertia value in meters_to_the_sixth.
        :type meters_to_the_sixth: float
        :return: A new instance of WarpingMomentOfInertia.
        :rtype: WarpingMomentOfInertia
        """
        return WarpingMomentOfInertia(meters_to_the_sixth, WarpingMomentOfInertiaUnits.MeterToTheSixth)

    
    @staticmethod
    def from_decimeters_to_the_sixth(decimeters_to_the_sixth: float):
        """
        Create a new instance of WarpingMomentOfInertia from a value in decimeters_to_the_sixth.

        

        :param meters: The WarpingMomentOfInertia value in decimeters_to_the_sixth.
        :type decimeters_to_the_sixth: float
        :return: A new instance of WarpingMomentOfInertia.
        :rtype: WarpingMomentOfInertia
        """
        return WarpingMomentOfInertia(decimeters_to_the_sixth, WarpingMomentOfInertiaUnits.DecimeterToTheSixth)

    
    @staticmethod
    def from_centimeters_to_the_sixth(centimeters_to_the_sixth: float):
        """
        Create a new instance of WarpingMomentOfInertia from a value in centimeters_to_the_sixth.

        

        :param meters: The WarpingMomentOfInertia value in centimeters_to_the_sixth.
        :type centimeters_to_the_sixth: float
        :return: A new instance of WarpingMomentOfInertia.
        :rtype: WarpingMomentOfInertia
        """
        return WarpingMomentOfInertia(centimeters_to_the_sixth, WarpingMomentOfInertiaUnits.CentimeterToTheSixth)

    
    @staticmethod
    def from_millimeters_to_the_sixth(millimeters_to_the_sixth: float):
        """
        Create a new instance of WarpingMomentOfInertia from a value in millimeters_to_the_sixth.

        

        :param meters: The WarpingMomentOfInertia value in millimeters_to_the_sixth.
        :type millimeters_to_the_sixth: float
        :return: A new instance of WarpingMomentOfInertia.
        :rtype: WarpingMomentOfInertia
        """
        return WarpingMomentOfInertia(millimeters_to_the_sixth, WarpingMomentOfInertiaUnits.MillimeterToTheSixth)

    
    @staticmethod
    def from_feet_to_the_sixth(feet_to_the_sixth: float):
        """
        Create a new instance of WarpingMomentOfInertia from a value in feet_to_the_sixth.

        

        :param meters: The WarpingMomentOfInertia value in feet_to_the_sixth.
        :type feet_to_the_sixth: float
        :return: A new instance of WarpingMomentOfInertia.
        :rtype: WarpingMomentOfInertia
        """
        return WarpingMomentOfInertia(feet_to_the_sixth, WarpingMomentOfInertiaUnits.FootToTheSixth)

    
    @staticmethod
    def from_inches_to_the_sixth(inches_to_the_sixth: float):
        """
        Create a new instance of WarpingMomentOfInertia from a value in inches_to_the_sixth.

        

        :param meters: The WarpingMomentOfInertia value in inches_to_the_sixth.
        :type inches_to_the_sixth: float
        :return: A new instance of WarpingMomentOfInertia.
        :rtype: WarpingMomentOfInertia
        """
        return WarpingMomentOfInertia(inches_to_the_sixth, WarpingMomentOfInertiaUnits.InchToTheSixth)

    
    @property
    def meters_to_the_sixth(self) -> float:
        """
        
        """
        if self.__meters_to_the_sixth != None:
            return self.__meters_to_the_sixth
        self.__meters_to_the_sixth = self.__convert_from_base(WarpingMomentOfInertiaUnits.MeterToTheSixth)
        return self.__meters_to_the_sixth

    
    @property
    def decimeters_to_the_sixth(self) -> float:
        """
        
        """
        if self.__decimeters_to_the_sixth != None:
            return self.__decimeters_to_the_sixth
        self.__decimeters_to_the_sixth = self.__convert_from_base(WarpingMomentOfInertiaUnits.DecimeterToTheSixth)
        return self.__decimeters_to_the_sixth

    
    @property
    def centimeters_to_the_sixth(self) -> float:
        """
        
        """
        if self.__centimeters_to_the_sixth != None:
            return self.__centimeters_to_the_sixth
        self.__centimeters_to_the_sixth = self.__convert_from_base(WarpingMomentOfInertiaUnits.CentimeterToTheSixth)
        return self.__centimeters_to_the_sixth

    
    @property
    def millimeters_to_the_sixth(self) -> float:
        """
        
        """
        if self.__millimeters_to_the_sixth != None:
            return self.__millimeters_to_the_sixth
        self.__millimeters_to_the_sixth = self.__convert_from_base(WarpingMomentOfInertiaUnits.MillimeterToTheSixth)
        return self.__millimeters_to_the_sixth

    
    @property
    def feet_to_the_sixth(self) -> float:
        """
        
        """
        if self.__feet_to_the_sixth != None:
            return self.__feet_to_the_sixth
        self.__feet_to_the_sixth = self.__convert_from_base(WarpingMomentOfInertiaUnits.FootToTheSixth)
        return self.__feet_to_the_sixth

    
    @property
    def inches_to_the_sixth(self) -> float:
        """
        
        """
        if self.__inches_to_the_sixth != None:
            return self.__inches_to_the_sixth
        self.__inches_to_the_sixth = self.__convert_from_base(WarpingMomentOfInertiaUnits.InchToTheSixth)
        return self.__inches_to_the_sixth

    
    def to_string(self, unit: WarpingMomentOfInertiaUnits = WarpingMomentOfInertiaUnits.MeterToTheSixth) -> string:
        """
        Format the WarpingMomentOfInertia to string.
        Note! the default format for WarpingMomentOfInertia is MeterToTheSixth.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == WarpingMomentOfInertiaUnits.MeterToTheSixth:
            return f"""{self.meters_to_the_sixth} m⁶"""
        
        if unit == WarpingMomentOfInertiaUnits.DecimeterToTheSixth:
            return f"""{self.decimeters_to_the_sixth} dm⁶"""
        
        if unit == WarpingMomentOfInertiaUnits.CentimeterToTheSixth:
            return f"""{self.centimeters_to_the_sixth} cm⁶"""
        
        if unit == WarpingMomentOfInertiaUnits.MillimeterToTheSixth:
            return f"""{self.millimeters_to_the_sixth} mm⁶"""
        
        if unit == WarpingMomentOfInertiaUnits.FootToTheSixth:
            return f"""{self.feet_to_the_sixth} ft⁶"""
        
        if unit == WarpingMomentOfInertiaUnits.InchToTheSixth:
            return f"""{self.inches_to_the_sixth} in⁶"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: WarpingMomentOfInertiaUnits = WarpingMomentOfInertiaUnits.MeterToTheSixth) -> string:
        """
        Get WarpingMomentOfInertia unit abbreviation.
        Note! the default abbreviation for WarpingMomentOfInertia is MeterToTheSixth.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == WarpingMomentOfInertiaUnits.MeterToTheSixth:
            return """m⁶"""
        
        if unit_abbreviation == WarpingMomentOfInertiaUnits.DecimeterToTheSixth:
            return """dm⁶"""
        
        if unit_abbreviation == WarpingMomentOfInertiaUnits.CentimeterToTheSixth:
            return """cm⁶"""
        
        if unit_abbreviation == WarpingMomentOfInertiaUnits.MillimeterToTheSixth:
            return """mm⁶"""
        
        if unit_abbreviation == WarpingMomentOfInertiaUnits.FootToTheSixth:
            return """ft⁶"""
        
        if unit_abbreviation == WarpingMomentOfInertiaUnits.InchToTheSixth:
            return """in⁶"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, WarpingMomentOfInertia):
            raise TypeError("unsupported operand type(s) for +: 'WarpingMomentOfInertia' and '{}'".format(type(other).__name__))
        return WarpingMomentOfInertia(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, WarpingMomentOfInertia):
            raise TypeError("unsupported operand type(s) for *: 'WarpingMomentOfInertia' and '{}'".format(type(other).__name__))
        return WarpingMomentOfInertia(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, WarpingMomentOfInertia):
            raise TypeError("unsupported operand type(s) for -: 'WarpingMomentOfInertia' and '{}'".format(type(other).__name__))
        return WarpingMomentOfInertia(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, WarpingMomentOfInertia):
            raise TypeError("unsupported operand type(s) for /: 'WarpingMomentOfInertia' and '{}'".format(type(other).__name__))
        return WarpingMomentOfInertia(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, WarpingMomentOfInertia):
            raise TypeError("unsupported operand type(s) for %: 'WarpingMomentOfInertia' and '{}'".format(type(other).__name__))
        return WarpingMomentOfInertia(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, WarpingMomentOfInertia):
            raise TypeError("unsupported operand type(s) for **: 'WarpingMomentOfInertia' and '{}'".format(type(other).__name__))
        return WarpingMomentOfInertia(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, WarpingMomentOfInertia):
            raise TypeError("unsupported operand type(s) for ==: 'WarpingMomentOfInertia' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, WarpingMomentOfInertia):
            raise TypeError("unsupported operand type(s) for <: 'WarpingMomentOfInertia' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, WarpingMomentOfInertia):
            raise TypeError("unsupported operand type(s) for >: 'WarpingMomentOfInertia' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, WarpingMomentOfInertia):
            raise TypeError("unsupported operand type(s) for <=: 'WarpingMomentOfInertia' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, WarpingMomentOfInertia):
            raise TypeError("unsupported operand type(s) for >=: 'WarpingMomentOfInertia' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class DurationUnits(Enum):
        """
            DurationUnits enumeration
        """
        
        Year365 = 'year365'
        """
            
        """
        
        Month30 = 'month30'
        """
            
        """
        
        Week = 'week'
        """
            
        """
        
        Day = 'day'
        """
            
        """
        
        Hour = 'hour'
        """
            
        """
        
        Minute = 'minute'
        """
            
        """
        
        Second = 'second'
        """
            
        """
        
        JulianYear = 'julian_year'
        """
            
        """
        
        Nanosecond = 'nanosecond'
        """
            
        """
        
        Microsecond = 'microsecond'
        """
            
        """
        
        Millisecond = 'millisecond'
        """
            
        """
        

class Duration:
    """
    Time is a dimension in which events can be ordered from the past through the present into the future, and also the measure of durations of events and the intervals between them.

    Args:
        value (float): The value.
        from_unit (DurationUnits): The Duration unit to create from, The default unit is Second
    """
    def __init__(self, value: float, from_unit: DurationUnits = DurationUnits.Second):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__years365 = None
        
        self.__months30 = None
        
        self.__weeks = None
        
        self.__days = None
        
        self.__hours = None
        
        self.__minutes = None
        
        self.__seconds = None
        
        self.__julian_years = None
        
        self.__nanoseconds = None
        
        self.__microseconds = None
        
        self.__milliseconds = None
        

    def __convert_from_base(self, from_unit: DurationUnits) -> float:
        value = self.__value
        
        if from_unit == DurationUnits.Year365:
            return (value / (365 * 24 * 3600))
        
        if from_unit == DurationUnits.Month30:
            return (value / (30 * 24 * 3600))
        
        if from_unit == DurationUnits.Week:
            return (value / (7 * 24 * 3600))
        
        if from_unit == DurationUnits.Day:
            return (value / (24 * 3600))
        
        if from_unit == DurationUnits.Hour:
            return (value / 3600)
        
        if from_unit == DurationUnits.Minute:
            return (value / 60)
        
        if from_unit == DurationUnits.Second:
            return (value)
        
        if from_unit == DurationUnits.JulianYear:
            return (value / (365.25 * 24 * 3600))
        
        if from_unit == DurationUnits.Nanosecond:
            return ((value) / 1e-09)
        
        if from_unit == DurationUnits.Microsecond:
            return ((value) / 1e-06)
        
        if from_unit == DurationUnits.Millisecond:
            return ((value) / 0.001)
        
        return None


    def __convert_to_base(self, value: float, to_unit: DurationUnits) -> float:
        
        if to_unit == DurationUnits.Year365:
            return (value * 365 * 24 * 3600)
        
        if to_unit == DurationUnits.Month30:
            return (value * 30 * 24 * 3600)
        
        if to_unit == DurationUnits.Week:
            return (value * 7 * 24 * 3600)
        
        if to_unit == DurationUnits.Day:
            return (value * 24 * 3600)
        
        if to_unit == DurationUnits.Hour:
            return (value * 3600)
        
        if to_unit == DurationUnits.Minute:
            return (value * 60)
        
        if to_unit == DurationUnits.Second:
            return (value)
        
        if to_unit == DurationUnits.JulianYear:
            return (value * 365.25 * 24 * 3600)
        
        if to_unit == DurationUnits.Nanosecond:
            return ((value) * 1e-09)
        
        if to_unit == DurationUnits.Microsecond:
            return ((value) * 1e-06)
        
        if to_unit == DurationUnits.Millisecond:
            return ((value) * 0.001)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_years365(years365: float):
        """
        Create a new instance of Duration from a value in years365.

        

        :param meters: The Duration value in years365.
        :type years365: float
        :return: A new instance of Duration.
        :rtype: Duration
        """
        return Duration(years365, DurationUnits.Year365)

    
    @staticmethod
    def from_months30(months30: float):
        """
        Create a new instance of Duration from a value in months30.

        

        :param meters: The Duration value in months30.
        :type months30: float
        :return: A new instance of Duration.
        :rtype: Duration
        """
        return Duration(months30, DurationUnits.Month30)

    
    @staticmethod
    def from_weeks(weeks: float):
        """
        Create a new instance of Duration from a value in weeks.

        

        :param meters: The Duration value in weeks.
        :type weeks: float
        :return: A new instance of Duration.
        :rtype: Duration
        """
        return Duration(weeks, DurationUnits.Week)

    
    @staticmethod
    def from_days(days: float):
        """
        Create a new instance of Duration from a value in days.

        

        :param meters: The Duration value in days.
        :type days: float
        :return: A new instance of Duration.
        :rtype: Duration
        """
        return Duration(days, DurationUnits.Day)

    
    @staticmethod
    def from_hours(hours: float):
        """
        Create a new instance of Duration from a value in hours.

        

        :param meters: The Duration value in hours.
        :type hours: float
        :return: A new instance of Duration.
        :rtype: Duration
        """
        return Duration(hours, DurationUnits.Hour)

    
    @staticmethod
    def from_minutes(minutes: float):
        """
        Create a new instance of Duration from a value in minutes.

        

        :param meters: The Duration value in minutes.
        :type minutes: float
        :return: A new instance of Duration.
        :rtype: Duration
        """
        return Duration(minutes, DurationUnits.Minute)

    
    @staticmethod
    def from_seconds(seconds: float):
        """
        Create a new instance of Duration from a value in seconds.

        

        :param meters: The Duration value in seconds.
        :type seconds: float
        :return: A new instance of Duration.
        :rtype: Duration
        """
        return Duration(seconds, DurationUnits.Second)

    
    @staticmethod
    def from_julian_years(julian_years: float):
        """
        Create a new instance of Duration from a value in julian_years.

        

        :param meters: The Duration value in julian_years.
        :type julian_years: float
        :return: A new instance of Duration.
        :rtype: Duration
        """
        return Duration(julian_years, DurationUnits.JulianYear)

    
    @staticmethod
    def from_nanoseconds(nanoseconds: float):
        """
        Create a new instance of Duration from a value in nanoseconds.

        

        :param meters: The Duration value in nanoseconds.
        :type nanoseconds: float
        :return: A new instance of Duration.
        :rtype: Duration
        """
        return Duration(nanoseconds, DurationUnits.Nanosecond)

    
    @staticmethod
    def from_microseconds(microseconds: float):
        """
        Create a new instance of Duration from a value in microseconds.

        

        :param meters: The Duration value in microseconds.
        :type microseconds: float
        :return: A new instance of Duration.
        :rtype: Duration
        """
        return Duration(microseconds, DurationUnits.Microsecond)

    
    @staticmethod
    def from_milliseconds(milliseconds: float):
        """
        Create a new instance of Duration from a value in milliseconds.

        

        :param meters: The Duration value in milliseconds.
        :type milliseconds: float
        :return: A new instance of Duration.
        :rtype: Duration
        """
        return Duration(milliseconds, DurationUnits.Millisecond)

    
    @property
    def years365(self) -> float:
        """
        
        """
        if self.__years365 != None:
            return self.__years365
        self.__years365 = self.__convert_from_base(DurationUnits.Year365)
        return self.__years365

    
    @property
    def months30(self) -> float:
        """
        
        """
        if self.__months30 != None:
            return self.__months30
        self.__months30 = self.__convert_from_base(DurationUnits.Month30)
        return self.__months30

    
    @property
    def weeks(self) -> float:
        """
        
        """
        if self.__weeks != None:
            return self.__weeks
        self.__weeks = self.__convert_from_base(DurationUnits.Week)
        return self.__weeks

    
    @property
    def days(self) -> float:
        """
        
        """
        if self.__days != None:
            return self.__days
        self.__days = self.__convert_from_base(DurationUnits.Day)
        return self.__days

    
    @property
    def hours(self) -> float:
        """
        
        """
        if self.__hours != None:
            return self.__hours
        self.__hours = self.__convert_from_base(DurationUnits.Hour)
        return self.__hours

    
    @property
    def minutes(self) -> float:
        """
        
        """
        if self.__minutes != None:
            return self.__minutes
        self.__minutes = self.__convert_from_base(DurationUnits.Minute)
        return self.__minutes

    
    @property
    def seconds(self) -> float:
        """
        
        """
        if self.__seconds != None:
            return self.__seconds
        self.__seconds = self.__convert_from_base(DurationUnits.Second)
        return self.__seconds

    
    @property
    def julian_years(self) -> float:
        """
        
        """
        if self.__julian_years != None:
            return self.__julian_years
        self.__julian_years = self.__convert_from_base(DurationUnits.JulianYear)
        return self.__julian_years

    
    @property
    def nanoseconds(self) -> float:
        """
        
        """
        if self.__nanoseconds != None:
            return self.__nanoseconds
        self.__nanoseconds = self.__convert_from_base(DurationUnits.Nanosecond)
        return self.__nanoseconds

    
    @property
    def microseconds(self) -> float:
        """
        
        """
        if self.__microseconds != None:
            return self.__microseconds
        self.__microseconds = self.__convert_from_base(DurationUnits.Microsecond)
        return self.__microseconds

    
    @property
    def milliseconds(self) -> float:
        """
        
        """
        if self.__milliseconds != None:
            return self.__milliseconds
        self.__milliseconds = self.__convert_from_base(DurationUnits.Millisecond)
        return self.__milliseconds

    
    def to_string(self, unit: DurationUnits = DurationUnits.Second) -> string:
        """
        Format the Duration to string.
        Note! the default format for Duration is Second.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == DurationUnits.Year365:
            return f"""{self.years365} yr"""
        
        if unit == DurationUnits.Month30:
            return f"""{self.months30} mo"""
        
        if unit == DurationUnits.Week:
            return f"""{self.weeks} wk"""
        
        if unit == DurationUnits.Day:
            return f"""{self.days} d"""
        
        if unit == DurationUnits.Hour:
            return f"""{self.hours} h"""
        
        if unit == DurationUnits.Minute:
            return f"""{self.minutes} m"""
        
        if unit == DurationUnits.Second:
            return f"""{self.seconds} s"""
        
        if unit == DurationUnits.JulianYear:
            return f"""{self.julian_years} jyr"""
        
        if unit == DurationUnits.Nanosecond:
            return f"""{self.nanoseconds} """
        
        if unit == DurationUnits.Microsecond:
            return f"""{self.microseconds} """
        
        if unit == DurationUnits.Millisecond:
            return f"""{self.milliseconds} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: DurationUnits = DurationUnits.Second) -> string:
        """
        Get Duration unit abbreviation.
        Note! the default abbreviation for Duration is Second.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == DurationUnits.Year365:
            return """yr"""
        
        if unit_abbreviation == DurationUnits.Month30:
            return """mo"""
        
        if unit_abbreviation == DurationUnits.Week:
            return """wk"""
        
        if unit_abbreviation == DurationUnits.Day:
            return """d"""
        
        if unit_abbreviation == DurationUnits.Hour:
            return """h"""
        
        if unit_abbreviation == DurationUnits.Minute:
            return """m"""
        
        if unit_abbreviation == DurationUnits.Second:
            return """s"""
        
        if unit_abbreviation == DurationUnits.JulianYear:
            return """jyr"""
        
        if unit_abbreviation == DurationUnits.Nanosecond:
            return """"""
        
        if unit_abbreviation == DurationUnits.Microsecond:
            return """"""
        
        if unit_abbreviation == DurationUnits.Millisecond:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, Duration):
            raise TypeError("unsupported operand type(s) for +: 'Duration' and '{}'".format(type(other).__name__))
        return Duration(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, Duration):
            raise TypeError("unsupported operand type(s) for *: 'Duration' and '{}'".format(type(other).__name__))
        return Duration(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, Duration):
            raise TypeError("unsupported operand type(s) for -: 'Duration' and '{}'".format(type(other).__name__))
        return Duration(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, Duration):
            raise TypeError("unsupported operand type(s) for /: 'Duration' and '{}'".format(type(other).__name__))
        return Duration(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, Duration):
            raise TypeError("unsupported operand type(s) for %: 'Duration' and '{}'".format(type(other).__name__))
        return Duration(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, Duration):
            raise TypeError("unsupported operand type(s) for **: 'Duration' and '{}'".format(type(other).__name__))
        return Duration(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, Duration):
            raise TypeError("unsupported operand type(s) for ==: 'Duration' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, Duration):
            raise TypeError("unsupported operand type(s) for <: 'Duration' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, Duration):
            raise TypeError("unsupported operand type(s) for >: 'Duration' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, Duration):
            raise TypeError("unsupported operand type(s) for <=: 'Duration' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, Duration):
            raise TypeError("unsupported operand type(s) for >=: 'Duration' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class PressureChangeRateUnits(Enum):
        """
            PressureChangeRateUnits enumeration
        """
        
        PascalPerSecond = 'pascal_per_second'
        """
            
        """
        
        PascalPerMinute = 'pascal_per_minute'
        """
            
        """
        
        MillimeterOfMercuryPerSecond = 'millimeter_of_mercury_per_second'
        """
            
        """
        
        AtmospherePerSecond = 'atmosphere_per_second'
        """
            
        """
        
        PoundForcePerSquareInchPerSecond = 'pound_force_per_square_inch_per_second'
        """
            
        """
        
        PoundForcePerSquareInchPerMinute = 'pound_force_per_square_inch_per_minute'
        """
            
        """
        
        KilopascalPerSecond = 'kilopascal_per_second'
        """
            
        """
        
        MegapascalPerSecond = 'megapascal_per_second'
        """
            
        """
        
        KilopascalPerMinute = 'kilopascal_per_minute'
        """
            
        """
        
        MegapascalPerMinute = 'megapascal_per_minute'
        """
            
        """
        
        KilopoundForcePerSquareInchPerSecond = 'kilopound_force_per_square_inch_per_second'
        """
            
        """
        
        MegapoundForcePerSquareInchPerSecond = 'megapound_force_per_square_inch_per_second'
        """
            
        """
        
        KilopoundForcePerSquareInchPerMinute = 'kilopound_force_per_square_inch_per_minute'
        """
            
        """
        
        MegapoundForcePerSquareInchPerMinute = 'megapound_force_per_square_inch_per_minute'
        """
            
        """
        

class PressureChangeRate:
    """
    Pressure change rate is the ratio of the pressure change to the time during which the change occurred (value of pressure changes per unit time).

    Args:
        value (float): The value.
        from_unit (PressureChangeRateUnits): The PressureChangeRate unit to create from, The default unit is PascalPerSecond
    """
    def __init__(self, value: float, from_unit: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__pascals_per_second = None
        
        self.__pascals_per_minute = None
        
        self.__millimeters_of_mercury_per_second = None
        
        self.__atmospheres_per_second = None
        
        self.__pounds_force_per_square_inch_per_second = None
        
        self.__pounds_force_per_square_inch_per_minute = None
        
        self.__kilopascals_per_second = None
        
        self.__megapascals_per_second = None
        
        self.__kilopascals_per_minute = None
        
        self.__megapascals_per_minute = None
        
        self.__kilopounds_force_per_square_inch_per_second = None
        
        self.__megapounds_force_per_square_inch_per_second = None
        
        self.__kilopounds_force_per_square_inch_per_minute = None
        
        self.__megapounds_force_per_square_inch_per_minute = None
        

    def __convert_from_base(self, from_unit: PressureChangeRateUnits) -> float:
        value = self.__value
        
        if from_unit == PressureChangeRateUnits.PascalPerSecond:
            return (value)
        
        if from_unit == PressureChangeRateUnits.PascalPerMinute:
            return (value * 60)
        
        if from_unit == PressureChangeRateUnits.MillimeterOfMercuryPerSecond:
            return (value / 133.322)
        
        if from_unit == PressureChangeRateUnits.AtmospherePerSecond:
            return (value / (1.01325 * 1e5))
        
        if from_unit == PressureChangeRateUnits.PoundForcePerSquareInchPerSecond:
            return (value / 6.894757293168361e3)
        
        if from_unit == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
            return (value / 6.894757293168361e3 * 60)
        
        if from_unit == PressureChangeRateUnits.KilopascalPerSecond:
            return ((value) / 1000.0)
        
        if from_unit == PressureChangeRateUnits.MegapascalPerSecond:
            return ((value) / 1000000.0)
        
        if from_unit == PressureChangeRateUnits.KilopascalPerMinute:
            return ((value * 60) / 1000.0)
        
        if from_unit == PressureChangeRateUnits.MegapascalPerMinute:
            return ((value * 60) / 1000000.0)
        
        if from_unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond:
            return ((value / 6.894757293168361e3) / 1000.0)
        
        if from_unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond:
            return ((value / 6.894757293168361e3) / 1000000.0)
        
        if from_unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute:
            return ((value / 6.894757293168361e3 * 60) / 1000.0)
        
        if from_unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
            return ((value / 6.894757293168361e3 * 60) / 1000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: PressureChangeRateUnits) -> float:
        
        if to_unit == PressureChangeRateUnits.PascalPerSecond:
            return (value)
        
        if to_unit == PressureChangeRateUnits.PascalPerMinute:
            return (value / 60)
        
        if to_unit == PressureChangeRateUnits.MillimeterOfMercuryPerSecond:
            return (value * 133.322)
        
        if to_unit == PressureChangeRateUnits.AtmospherePerSecond:
            return (value * 1.01325 * 1e5)
        
        if to_unit == PressureChangeRateUnits.PoundForcePerSquareInchPerSecond:
            return (value * 6.894757293168361e3)
        
        if to_unit == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
            return (value * 6.894757293168361e3 / 60)
        
        if to_unit == PressureChangeRateUnits.KilopascalPerSecond:
            return ((value) * 1000.0)
        
        if to_unit == PressureChangeRateUnits.MegapascalPerSecond:
            return ((value) * 1000000.0)
        
        if to_unit == PressureChangeRateUnits.KilopascalPerMinute:
            return ((value / 60) * 1000.0)
        
        if to_unit == PressureChangeRateUnits.MegapascalPerMinute:
            return ((value / 60) * 1000000.0)
        
        if to_unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond:
            return ((value * 6.894757293168361e3) * 1000.0)
        
        if to_unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond:
            return ((value * 6.894757293168361e3) * 1000000.0)
        
        if to_unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute:
            return ((value * 6.894757293168361e3 / 60) * 1000.0)
        
        if to_unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
            return ((value * 6.894757293168361e3 / 60) * 1000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_pascals_per_second(pascals_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in pascals_per_second.

        

        :param meters: The PressureChangeRate value in pascals_per_second.
        :type pascals_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(pascals_per_second, PressureChangeRateUnits.PascalPerSecond)

    
    @staticmethod
    def from_pascals_per_minute(pascals_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in pascals_per_minute.

        

        :param meters: The PressureChangeRate value in pascals_per_minute.
        :type pascals_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(pascals_per_minute, PressureChangeRateUnits.PascalPerMinute)

    
    @staticmethod
    def from_millimeters_of_mercury_per_second(millimeters_of_mercury_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in millimeters_of_mercury_per_second.

        

        :param meters: The PressureChangeRate value in millimeters_of_mercury_per_second.
        :type millimeters_of_mercury_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(millimeters_of_mercury_per_second, PressureChangeRateUnits.MillimeterOfMercuryPerSecond)

    
    @staticmethod
    def from_atmospheres_per_second(atmospheres_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in atmospheres_per_second.

        

        :param meters: The PressureChangeRate value in atmospheres_per_second.
        :type atmospheres_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(atmospheres_per_second, PressureChangeRateUnits.AtmospherePerSecond)

    
    @staticmethod
    def from_pounds_force_per_square_inch_per_second(pounds_force_per_square_inch_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in pounds_force_per_square_inch_per_second.

        

        :param meters: The PressureChangeRate value in pounds_force_per_square_inch_per_second.
        :type pounds_force_per_square_inch_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(pounds_force_per_square_inch_per_second, PressureChangeRateUnits.PoundForcePerSquareInchPerSecond)

    
    @staticmethod
    def from_pounds_force_per_square_inch_per_minute(pounds_force_per_square_inch_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in pounds_force_per_square_inch_per_minute.

        

        :param meters: The PressureChangeRate value in pounds_force_per_square_inch_per_minute.
        :type pounds_force_per_square_inch_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(pounds_force_per_square_inch_per_minute, PressureChangeRateUnits.PoundForcePerSquareInchPerMinute)

    
    @staticmethod
    def from_kilopascals_per_second(kilopascals_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in kilopascals_per_second.

        

        :param meters: The PressureChangeRate value in kilopascals_per_second.
        :type kilopascals_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(kilopascals_per_second, PressureChangeRateUnits.KilopascalPerSecond)

    
    @staticmethod
    def from_megapascals_per_second(megapascals_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in megapascals_per_second.

        

        :param meters: The PressureChangeRate value in megapascals_per_second.
        :type megapascals_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(megapascals_per_second, PressureChangeRateUnits.MegapascalPerSecond)

    
    @staticmethod
    def from_kilopascals_per_minute(kilopascals_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in kilopascals_per_minute.

        

        :param meters: The PressureChangeRate value in kilopascals_per_minute.
        :type kilopascals_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(kilopascals_per_minute, PressureChangeRateUnits.KilopascalPerMinute)

    
    @staticmethod
    def from_megapascals_per_minute(megapascals_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in megapascals_per_minute.

        

        :param meters: The PressureChangeRate value in megapascals_per_minute.
        :type megapascals_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(megapascals_per_minute, PressureChangeRateUnits.MegapascalPerMinute)

    
    @staticmethod
    def from_kilopounds_force_per_square_inch_per_second(kilopounds_force_per_square_inch_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in kilopounds_force_per_square_inch_per_second.

        

        :param meters: The PressureChangeRate value in kilopounds_force_per_square_inch_per_second.
        :type kilopounds_force_per_square_inch_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(kilopounds_force_per_square_inch_per_second, PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond)

    
    @staticmethod
    def from_megapounds_force_per_square_inch_per_second(megapounds_force_per_square_inch_per_second: float):
        """
        Create a new instance of PressureChangeRate from a value in megapounds_force_per_square_inch_per_second.

        

        :param meters: The PressureChangeRate value in megapounds_force_per_square_inch_per_second.
        :type megapounds_force_per_square_inch_per_second: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(megapounds_force_per_square_inch_per_second, PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond)

    
    @staticmethod
    def from_kilopounds_force_per_square_inch_per_minute(kilopounds_force_per_square_inch_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in kilopounds_force_per_square_inch_per_minute.

        

        :param meters: The PressureChangeRate value in kilopounds_force_per_square_inch_per_minute.
        :type kilopounds_force_per_square_inch_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(kilopounds_force_per_square_inch_per_minute, PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute)

    
    @staticmethod
    def from_megapounds_force_per_square_inch_per_minute(megapounds_force_per_square_inch_per_minute: float):
        """
        Create a new instance of PressureChangeRate from a value in megapounds_force_per_square_inch_per_minute.

        

        :param meters: The PressureChangeRate value in megapounds_force_per_square_inch_per_minute.
        :type megapounds_force_per_square_inch_per_minute: float
        :return: A new instance of PressureChangeRate.
        :rtype: PressureChangeRate
        """
        return PressureChangeRate(megapounds_force_per_square_inch_per_minute, PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute)

    
    @property
    def pascals_per_second(self) -> float:
        """
        
        """
        if self.__pascals_per_second != None:
            return self.__pascals_per_second
        self.__pascals_per_second = self.__convert_from_base(PressureChangeRateUnits.PascalPerSecond)
        return self.__pascals_per_second

    
    @property
    def pascals_per_minute(self) -> float:
        """
        
        """
        if self.__pascals_per_minute != None:
            return self.__pascals_per_minute
        self.__pascals_per_minute = self.__convert_from_base(PressureChangeRateUnits.PascalPerMinute)
        return self.__pascals_per_minute

    
    @property
    def millimeters_of_mercury_per_second(self) -> float:
        """
        
        """
        if self.__millimeters_of_mercury_per_second != None:
            return self.__millimeters_of_mercury_per_second
        self.__millimeters_of_mercury_per_second = self.__convert_from_base(PressureChangeRateUnits.MillimeterOfMercuryPerSecond)
        return self.__millimeters_of_mercury_per_second

    
    @property
    def atmospheres_per_second(self) -> float:
        """
        
        """
        if self.__atmospheres_per_second != None:
            return self.__atmospheres_per_second
        self.__atmospheres_per_second = self.__convert_from_base(PressureChangeRateUnits.AtmospherePerSecond)
        return self.__atmospheres_per_second

    
    @property
    def pounds_force_per_square_inch_per_second(self) -> float:
        """
        
        """
        if self.__pounds_force_per_square_inch_per_second != None:
            return self.__pounds_force_per_square_inch_per_second
        self.__pounds_force_per_square_inch_per_second = self.__convert_from_base(PressureChangeRateUnits.PoundForcePerSquareInchPerSecond)
        return self.__pounds_force_per_square_inch_per_second

    
    @property
    def pounds_force_per_square_inch_per_minute(self) -> float:
        """
        
        """
        if self.__pounds_force_per_square_inch_per_minute != None:
            return self.__pounds_force_per_square_inch_per_minute
        self.__pounds_force_per_square_inch_per_minute = self.__convert_from_base(PressureChangeRateUnits.PoundForcePerSquareInchPerMinute)
        return self.__pounds_force_per_square_inch_per_minute

    
    @property
    def kilopascals_per_second(self) -> float:
        """
        
        """
        if self.__kilopascals_per_second != None:
            return self.__kilopascals_per_second
        self.__kilopascals_per_second = self.__convert_from_base(PressureChangeRateUnits.KilopascalPerSecond)
        return self.__kilopascals_per_second

    
    @property
    def megapascals_per_second(self) -> float:
        """
        
        """
        if self.__megapascals_per_second != None:
            return self.__megapascals_per_second
        self.__megapascals_per_second = self.__convert_from_base(PressureChangeRateUnits.MegapascalPerSecond)
        return self.__megapascals_per_second

    
    @property
    def kilopascals_per_minute(self) -> float:
        """
        
        """
        if self.__kilopascals_per_minute != None:
            return self.__kilopascals_per_minute
        self.__kilopascals_per_minute = self.__convert_from_base(PressureChangeRateUnits.KilopascalPerMinute)
        return self.__kilopascals_per_minute

    
    @property
    def megapascals_per_minute(self) -> float:
        """
        
        """
        if self.__megapascals_per_minute != None:
            return self.__megapascals_per_minute
        self.__megapascals_per_minute = self.__convert_from_base(PressureChangeRateUnits.MegapascalPerMinute)
        return self.__megapascals_per_minute

    
    @property
    def kilopounds_force_per_square_inch_per_second(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_square_inch_per_second != None:
            return self.__kilopounds_force_per_square_inch_per_second
        self.__kilopounds_force_per_square_inch_per_second = self.__convert_from_base(PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond)
        return self.__kilopounds_force_per_square_inch_per_second

    
    @property
    def megapounds_force_per_square_inch_per_second(self) -> float:
        """
        
        """
        if self.__megapounds_force_per_square_inch_per_second != None:
            return self.__megapounds_force_per_square_inch_per_second
        self.__megapounds_force_per_square_inch_per_second = self.__convert_from_base(PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond)
        return self.__megapounds_force_per_square_inch_per_second

    
    @property
    def kilopounds_force_per_square_inch_per_minute(self) -> float:
        """
        
        """
        if self.__kilopounds_force_per_square_inch_per_minute != None:
            return self.__kilopounds_force_per_square_inch_per_minute
        self.__kilopounds_force_per_square_inch_per_minute = self.__convert_from_base(PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute)
        return self.__kilopounds_force_per_square_inch_per_minute

    
    @property
    def megapounds_force_per_square_inch_per_minute(self) -> float:
        """
        
        """
        if self.__megapounds_force_per_square_inch_per_minute != None:
            return self.__megapounds_force_per_square_inch_per_minute
        self.__megapounds_force_per_square_inch_per_minute = self.__convert_from_base(PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute)
        return self.__megapounds_force_per_square_inch_per_minute

    
    def to_string(self, unit: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond) -> string:
        """
        Format the PressureChangeRate to string.
        Note! the default format for PressureChangeRate is PascalPerSecond.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == PressureChangeRateUnits.PascalPerSecond:
            return f"""{self.pascals_per_second} Pa/s"""
        
        if unit == PressureChangeRateUnits.PascalPerMinute:
            return f"""{self.pascals_per_minute} Pa/min"""
        
        if unit == PressureChangeRateUnits.MillimeterOfMercuryPerSecond:
            return f"""{self.millimeters_of_mercury_per_second} mmHg/s"""
        
        if unit == PressureChangeRateUnits.AtmospherePerSecond:
            return f"""{self.atmospheres_per_second} atm/s"""
        
        if unit == PressureChangeRateUnits.PoundForcePerSquareInchPerSecond:
            return f"""{self.pounds_force_per_square_inch_per_second} psi/s"""
        
        if unit == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
            return f"""{self.pounds_force_per_square_inch_per_minute} psi/min"""
        
        if unit == PressureChangeRateUnits.KilopascalPerSecond:
            return f"""{self.kilopascals_per_second} """
        
        if unit == PressureChangeRateUnits.MegapascalPerSecond:
            return f"""{self.megapascals_per_second} """
        
        if unit == PressureChangeRateUnits.KilopascalPerMinute:
            return f"""{self.kilopascals_per_minute} """
        
        if unit == PressureChangeRateUnits.MegapascalPerMinute:
            return f"""{self.megapascals_per_minute} """
        
        if unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond:
            return f"""{self.kilopounds_force_per_square_inch_per_second} """
        
        if unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond:
            return f"""{self.megapounds_force_per_square_inch_per_second} """
        
        if unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute:
            return f"""{self.kilopounds_force_per_square_inch_per_minute} """
        
        if unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
            return f"""{self.megapounds_force_per_square_inch_per_minute} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond) -> string:
        """
        Get PressureChangeRate unit abbreviation.
        Note! the default abbreviation for PressureChangeRate is PascalPerSecond.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == PressureChangeRateUnits.PascalPerSecond:
            return """Pa/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.PascalPerMinute:
            return """Pa/min"""
        
        if unit_abbreviation == PressureChangeRateUnits.MillimeterOfMercuryPerSecond:
            return """mmHg/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.AtmospherePerSecond:
            return """atm/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.PoundForcePerSquareInchPerSecond:
            return """psi/s"""
        
        if unit_abbreviation == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
            return """psi/min"""
        
        if unit_abbreviation == PressureChangeRateUnits.KilopascalPerSecond:
            return """"""
        
        if unit_abbreviation == PressureChangeRateUnits.MegapascalPerSecond:
            return """"""
        
        if unit_abbreviation == PressureChangeRateUnits.KilopascalPerMinute:
            return """"""
        
        if unit_abbreviation == PressureChangeRateUnits.MegapascalPerMinute:
            return """"""
        
        if unit_abbreviation == PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond:
            return """"""
        
        if unit_abbreviation == PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond:
            return """"""
        
        if unit_abbreviation == PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute:
            return """"""
        
        if unit_abbreviation == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, PressureChangeRate):
            raise TypeError("unsupported operand type(s) for +: 'PressureChangeRate' and '{}'".format(type(other).__name__))
        return PressureChangeRate(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, PressureChangeRate):
            raise TypeError("unsupported operand type(s) for *: 'PressureChangeRate' and '{}'".format(type(other).__name__))
        return PressureChangeRate(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, PressureChangeRate):
            raise TypeError("unsupported operand type(s) for -: 'PressureChangeRate' and '{}'".format(type(other).__name__))
        return PressureChangeRate(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, PressureChangeRate):
            raise TypeError("unsupported operand type(s) for /: 'PressureChangeRate' and '{}'".format(type(other).__name__))
        return PressureChangeRate(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, PressureChangeRate):
            raise TypeError("unsupported operand type(s) for %: 'PressureChangeRate' and '{}'".format(type(other).__name__))
        return PressureChangeRate(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, PressureChangeRate):
            raise TypeError("unsupported operand type(s) for **: 'PressureChangeRate' and '{}'".format(type(other).__name__))
        return PressureChangeRate(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, PressureChangeRate):
            raise TypeError("unsupported operand type(s) for ==: 'PressureChangeRate' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, PressureChangeRate):
            raise TypeError("unsupported operand type(s) for <: 'PressureChangeRate' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, PressureChangeRate):
            raise TypeError("unsupported operand type(s) for >: 'PressureChangeRate' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, PressureChangeRate):
            raise TypeError("unsupported operand type(s) for <=: 'PressureChangeRate' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, PressureChangeRate):
            raise TypeError("unsupported operand type(s) for >=: 'PressureChangeRate' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from .units.absorbed_dose_of_ionizing_radiation import AbsorbedDoseOfIonizingRadiation, AbsorbedDoseOfIonizingRadiationUnits
from .units.acceleration import Acceleration, AccelerationUnits
from .units.amount_of_substance import AmountOfSubstance, AmountOfSubstanceUnits
from .units.amplitude_ratio import AmplitudeRatio, AmplitudeRatioUnits
from .units.angle import Angle, AngleUnits
from .units.apparent_energy import ApparentEnergy, ApparentEnergyUnits
from .units.apparent_power import ApparentPower, ApparentPowerUnits
from .units.area import Area, AreaUnits
from .units.area_density import AreaDensity, AreaDensityUnits
from .units.area_moment_of_inertia import AreaMomentOfInertia, AreaMomentOfInertiaUnits
from .units.bit_rate import BitRate, BitRateUnits
from .units.brake_specific_fuel_consumption import BrakeSpecificFuelConsumption, BrakeSpecificFuelConsumptionUnits
from .units.capacitance import Capacitance, CapacitanceUnits
from .units.coefficient_of_thermal_expansion import CoefficientOfThermalExpansion, CoefficientOfThermalExpansionUnits
from .units.compressibility import Compressibility, CompressibilityUnits
from .units.density import Density, DensityUnits
from .units.duration import Duration, DurationUnits
from .units.dynamic_viscosity import DynamicViscosity, DynamicViscosityUnits
from .units.electric_admittance import ElectricAdmittance, ElectricAdmittanceUnits
from .units.electric_charge import ElectricCharge, ElectricChargeUnits
from .units.electric_charge_density import ElectricChargeDensity, ElectricChargeDensityUnits
from .units.electric_conductance import ElectricConductance, ElectricConductanceUnits
from .units.electric_conductivity import ElectricConductivity, ElectricConductivityUnits
from .units.electric_current import ElectricCurrent, ElectricCurrentUnits
from .units.electric_current_density import ElectricCurrentDensity, ElectricCurrentDensityUnits
from .units.electric_current_gradient import ElectricCurrentGradient, ElectricCurrentGradientUnits
from .units.electric_field import ElectricField, ElectricFieldUnits
from .units.electric_inductance import ElectricInductance, ElectricInductanceUnits
from .units.electric_potential import ElectricPotential, ElectricPotentialUnits
from .units.electric_potential_ac import ElectricPotentialAc, ElectricPotentialAcUnits
from .units.electric_potential_change_rate import ElectricPotentialChangeRate, ElectricPotentialChangeRateUnits
from .units.electric_potential_dc import ElectricPotentialDc, ElectricPotentialDcUnits
from .units.electric_resistance import ElectricResistance, ElectricResistanceUnits
from .units.electric_resistivity import ElectricResistivity, ElectricResistivityUnits
from .units.electric_surface_charge_density import ElectricSurfaceChargeDensity, ElectricSurfaceChargeDensityUnits
from .units.energy import Energy, EnergyUnits
from .units.energy_density import EnergyDensity, EnergyDensityUnits
from .units.entropy import Entropy, EntropyUnits
from .units.force import Force, ForceUnits
from .units.force_change_rate import ForceChangeRate, ForceChangeRateUnits
from .units.force_per_length import ForcePerLength, ForcePerLengthUnits
from .units.frequency import Frequency, FrequencyUnits
from .units.fuel_efficiency import FuelEfficiency, FuelEfficiencyUnits
from .units.heat_flux import HeatFlux, HeatFluxUnits
from .units.heat_transfer_coefficient import HeatTransferCoefficient, HeatTransferCoefficientUnits
from .units.illuminance import Illuminance, IlluminanceUnits
from .units.impulse import Impulse, ImpulseUnits
from .units.information import Information, InformationUnits
from .units.irradiance import Irradiance, IrradianceUnits
from .units.irradiation import Irradiation, IrradiationUnits
from .units.jerk import Jerk, JerkUnits
from .units.kinematic_viscosity import KinematicViscosity, KinematicViscosityUnits
from .units.leak_rate import LeakRate, LeakRateUnits
from .units.length import Length, LengthUnits
from .units.level import Level, LevelUnits
from .units.linear_density import LinearDensity, LinearDensityUnits
from .units.linear_power_density import LinearPowerDensity, LinearPowerDensityUnits
from .units.luminance import Luminance, LuminanceUnits
from .units.luminosity import Luminosity, LuminosityUnits
from .units.luminous_flux import LuminousFlux, LuminousFluxUnits
from .units.luminous_intensity import LuminousIntensity, LuminousIntensityUnits
from .units.magnetic_field import MagneticField, MagneticFieldUnits
from .units.magnetic_flux import MagneticFlux, MagneticFluxUnits
from .units.magnetization import Magnetization, MagnetizationUnits
from .units.mass import Mass, MassUnits
from .units.mass_concentration import MassConcentration, MassConcentrationUnits
from .units.mass_flow import MassFlow, MassFlowUnits
from .units.mass_flux import MassFlux, MassFluxUnits
from .units.mass_fraction import MassFraction, MassFractionUnits
from .units.mass_moment_of_inertia import MassMomentOfInertia, MassMomentOfInertiaUnits
from .units.molar_energy import MolarEnergy, MolarEnergyUnits
from .units.molar_entropy import MolarEntropy, MolarEntropyUnits
from .units.molar_flow import MolarFlow, MolarFlowUnits
from .units.molar_mass import MolarMass, MolarMassUnits
from .units.molarity import Molarity, MolarityUnits
from .units.permeability import Permeability, PermeabilityUnits
from .units.permittivity import Permittivity, PermittivityUnits
from .units.porous_medium_permeability import PorousMediumPermeability, PorousMediumPermeabilityUnits
from .units.power import Power, PowerUnits
from .units.power_density import PowerDensity, PowerDensityUnits
from .units.power_ratio import PowerRatio, PowerRatioUnits
from .units.pressure import Pressure, PressureUnits
from .units.pressure_change_rate import PressureChangeRate, PressureChangeRateUnits
from .units.ratio import Ratio, RatioUnits
from .units.ratio_change_rate import RatioChangeRate, RatioChangeRateUnits
from .units.reactive_energy import ReactiveEnergy, ReactiveEnergyUnits
from .units.reactive_power import ReactivePower, ReactivePowerUnits
from .units.reciprocal_area import ReciprocalArea, ReciprocalAreaUnits
from .units.reciprocal_length import ReciprocalLength, ReciprocalLengthUnits
from .units.relative_humidity import RelativeHumidity, RelativeHumidityUnits
from .units.rotational_acceleration import RotationalAcceleration, RotationalAccelerationUnits
from .units.rotational_speed import RotationalSpeed, RotationalSpeedUnits
from .units.rotational_stiffness import RotationalStiffness, RotationalStiffnessUnits
from .units.rotational_stiffness_per_length import RotationalStiffnessPerLength, RotationalStiffnessPerLengthUnits
from .units.scalar import Scalar, ScalarUnits
from .units.solid_angle import SolidAngle, SolidAngleUnits
from .units.specific_energy import SpecificEnergy, SpecificEnergyUnits
from .units.specific_entropy import SpecificEntropy, SpecificEntropyUnits
from .units.specific_fuel_consumption import SpecificFuelConsumption, SpecificFuelConsumptionUnits
from .units.specific_volume import SpecificVolume, SpecificVolumeUnits
from .units.specific_weight import SpecificWeight, SpecificWeightUnits
from .units.speed import Speed, SpeedUnits
from .units.standard_volume_flow import StandardVolumeFlow, StandardVolumeFlowUnits
from .units.temperature import Temperature, TemperatureUnits
from .units.temperature_change_rate import TemperatureChangeRate, TemperatureChangeRateUnits
from .units.temperature_delta import TemperatureDelta, TemperatureDeltaUnits
from .units.temperature_gradient import TemperatureGradient, TemperatureGradientUnits
from .units.thermal_conductivity import ThermalConductivity, ThermalConductivityUnits
from .units.thermal_resistance import ThermalResistance, ThermalResistanceUnits
from .units.torque import Torque, TorqueUnits
from .units.torque_per_length import TorquePerLength, TorquePerLengthUnits
from .units.turbidity import Turbidity, TurbidityUnits
from .units.vitamin_a import VitaminA, VitaminAUnits
from .units.volume import Volume, VolumeUnits
from .units.volume_concentration import VolumeConcentration, VolumeConcentrationUnits
from .units.volume_flow import VolumeFlow, VolumeFlowUnits
from .units.volume_flow_per_area import VolumeFlowPerArea, VolumeFlowPerAreaUnits
from .units.volume_per_length import VolumePerLength, VolumePerLengthUnits
from .units.volumetric_heat_capacity import VolumetricHeatCapacity, VolumetricHeatCapacityUnits
from .units.warping_moment_of_inertia import WarpingMomentOfInertia, WarpingMomentOfInertiaUnits


__all__ = [
 'AbsorbedDoseOfIonizingRadiation', 'AbsorbedDoseOfIonizingRadiationUnits',
 'Acceleration', 'AccelerationUnits',
 'AmountOfSubstance', 'AmountOfSubstanceUnits',
 'AmplitudeRatio', 'AmplitudeRatioUnits',
 'Angle', 'AngleUnits',
 'ApparentEnergy', 'ApparentEnergyUnits',
 'ApparentPower', 'ApparentPowerUnits',
 'Area', 'AreaUnits',
 'AreaDensity', 'AreaDensityUnits',
 'AreaMomentOfInertia', 'AreaMomentOfInertiaUnits',
 'BitRate', 'BitRateUnits',
 'BrakeSpecificFuelConsumption', 'BrakeSpecificFuelConsumptionUnits',
 'Capacitance', 'CapacitanceUnits',
 'CoefficientOfThermalExpansion', 'CoefficientOfThermalExpansionUnits',
 'Compressibility', 'CompressibilityUnits',
 'Density', 'DensityUnits',
 'Duration', 'DurationUnits',
 'DynamicViscosity', 'DynamicViscosityUnits',
 'ElectricAdmittance', 'ElectricAdmittanceUnits',
 'ElectricCharge', 'ElectricChargeUnits',
 'ElectricChargeDensity', 'ElectricChargeDensityUnits',
 'ElectricConductance', 'ElectricConductanceUnits',
 'ElectricConductivity', 'ElectricConductivityUnits',
 'ElectricCurrent', 'ElectricCurrentUnits',
 'ElectricCurrentDensity', 'ElectricCurrentDensityUnits',
 'ElectricCurrentGradient', 'ElectricCurrentGradientUnits',
 'ElectricField', 'ElectricFieldUnits',
 'ElectricInductance', 'ElectricInductanceUnits',
 'ElectricPotential', 'ElectricPotentialUnits',
 'ElectricPotentialAc', 'ElectricPotentialAcUnits',
 'ElectricPotentialChangeRate', 'ElectricPotentialChangeRateUnits',
 'ElectricPotentialDc', 'ElectricPotentialDcUnits',
 'ElectricResistance', 'ElectricResistanceUnits',
 'ElectricResistivity', 'ElectricResistivityUnits',
 'ElectricSurfaceChargeDensity', 'ElectricSurfaceChargeDensityUnits',
 'Energy', 'EnergyUnits',
 'EnergyDensity', 'EnergyDensityUnits',
 'Entropy', 'EntropyUnits',
 'Force', 'ForceUnits',
 'ForceChangeRate', 'ForceChangeRateUnits',
 'ForcePerLength', 'ForcePerLengthUnits',
 'Frequency', 'FrequencyUnits',
 'FuelEfficiency', 'FuelEfficiencyUnits',
 'HeatFlux', 'HeatFluxUnits',
 'HeatTransferCoefficient', 'HeatTransferCoefficientUnits',
 'Illuminance', 'IlluminanceUnits',
 'Impulse', 'ImpulseUnits',
 'Information', 'InformationUnits',
 'Irradiance', 'IrradianceUnits',
 'Irradiation', 'IrradiationUnits',
 'Jerk', 'JerkUnits',
 'KinematicViscosity', 'KinematicViscosityUnits',
 'LeakRate', 'LeakRateUnits',
 'Length', 'LengthUnits',
 'Level', 'LevelUnits',
 'LinearDensity', 'LinearDensityUnits',
 'LinearPowerDensity', 'LinearPowerDensityUnits',
 'Luminance', 'LuminanceUnits',
 'Luminosity', 'LuminosityUnits',
 'LuminousFlux', 'LuminousFluxUnits',
 'LuminousIntensity', 'LuminousIntensityUnits',
 'MagneticField', 'MagneticFieldUnits',
 'MagneticFlux', 'MagneticFluxUnits',
 'Magnetization', 'MagnetizationUnits',
 'Mass', 'MassUnits',
 'MassConcentration', 'MassConcentrationUnits',
 'MassFlow', 'MassFlowUnits',
 'MassFlux', 'MassFluxUnits',
 'MassFraction', 'MassFractionUnits',
 'MassMomentOfInertia', 'MassMomentOfInertiaUnits',
 'MolarEnergy', 'MolarEnergyUnits',
 'MolarEntropy', 'MolarEntropyUnits',
 'MolarFlow', 'MolarFlowUnits',
 'MolarMass', 'MolarMassUnits',
 'Molarity', 'MolarityUnits',
 'Permeability', 'PermeabilityUnits',
 'Permittivity', 'PermittivityUnits',
 'PorousMediumPermeability', 'PorousMediumPermeabilityUnits',
 'Power', 'PowerUnits',
 'PowerDensity', 'PowerDensityUnits',
 'PowerRatio', 'PowerRatioUnits',
 'Pressure', 'PressureUnits',
 'PressureChangeRate', 'PressureChangeRateUnits',
 'Ratio', 'RatioUnits',
 'RatioChangeRate', 'RatioChangeRateUnits',
 'ReactiveEnergy', 'ReactiveEnergyUnits',
 'ReactivePower', 'ReactivePowerUnits',
 'ReciprocalArea', 'ReciprocalAreaUnits',
 'ReciprocalLength', 'ReciprocalLengthUnits',
 'RelativeHumidity', 'RelativeHumidityUnits',
 'RotationalAcceleration', 'RotationalAccelerationUnits',
 'RotationalSpeed', 'RotationalSpeedUnits',
 'RotationalStiffness', 'RotationalStiffnessUnits',
 'RotationalStiffnessPerLength', 'RotationalStiffnessPerLengthUnits',
 'Scalar', 'ScalarUnits',
 'SolidAngle', 'SolidAngleUnits',
 'SpecificEnergy', 'SpecificEnergyUnits',
 'SpecificEntropy', 'SpecificEntropyUnits',
 'SpecificFuelConsumption', 'SpecificFuelConsumptionUnits',
 'SpecificVolume', 'SpecificVolumeUnits',
 'SpecificWeight', 'SpecificWeightUnits',
 'Speed', 'SpeedUnits',
 'StandardVolumeFlow', 'StandardVolumeFlowUnits',
 'Temperature', 'TemperatureUnits',
 'TemperatureChangeRate', 'TemperatureChangeRateUnits',
 'TemperatureDelta', 'TemperatureDeltaUnits',
 'TemperatureGradient', 'TemperatureGradientUnits',
 'ThermalConductivity', 'ThermalConductivityUnits',
 'ThermalResistance', 'ThermalResistanceUnits',
 'Torque', 'TorqueUnits',
 'TorquePerLength', 'TorquePerLengthUnits',
 'Turbidity', 'TurbidityUnits',
 'VitaminA', 'VitaminAUnits',
 'Volume', 'VolumeUnits',
 'VolumeConcentration', 'VolumeConcentrationUnits',
 'VolumeFlow', 'VolumeFlowUnits',
 'VolumeFlowPerArea', 'VolumeFlowPerAreaUnits',
 'VolumePerLength', 'VolumePerLengthUnits',
 'VolumetricHeatCapacity', 'VolumetricHeatCapacityUnits',
 'WarpingMomentOfInertia', 'WarpingMomentOfInertiaUnits',
]


from enum import Enum
import math
import string


class LinearDensityUnits(Enum):
        """
            LinearDensityUnits enumeration
        """
        
        GramPerMillimeter = 'gram_per_millimeter'
        """
            
        """
        
        GramPerCentimeter = 'gram_per_centimeter'
        """
            
        """
        
        GramPerMeter = 'gram_per_meter'
        """
            
        """
        
        PoundPerInch = 'pound_per_inch'
        """
            
        """
        
        PoundPerFoot = 'pound_per_foot'
        """
            
        """
        
        MicrogramPerMillimeter = 'microgram_per_millimeter'
        """
            
        """
        
        MilligramPerMillimeter = 'milligram_per_millimeter'
        """
            
        """
        
        KilogramPerMillimeter = 'kilogram_per_millimeter'
        """
            
        """
        
        MicrogramPerCentimeter = 'microgram_per_centimeter'
        """
            
        """
        
        MilligramPerCentimeter = 'milligram_per_centimeter'
        """
            
        """
        
        KilogramPerCentimeter = 'kilogram_per_centimeter'
        """
            
        """
        
        MicrogramPerMeter = 'microgram_per_meter'
        """
            
        """
        
        MilligramPerMeter = 'milligram_per_meter'
        """
            
        """
        
        KilogramPerMeter = 'kilogram_per_meter'
        """
            
        """
        

class LinearDensity:
    """
    The Linear Density, or more precisely, the linear mass density, of a substance is its mass per unit length.  The term linear density is most often used when describing the characteristics of one-dimensional objects, although linear density can also be used to describe the density of a three-dimensional quantity along one particular dimension.

    Args:
        value (float): The value.
        from_unit (LinearDensityUnits): The LinearDensity unit to create from, The default unit is KilogramPerMeter
    """
    def __init__(self, value: float, from_unit: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__grams_per_millimeter = None
        
        self.__grams_per_centimeter = None
        
        self.__grams_per_meter = None
        
        self.__pounds_per_inch = None
        
        self.__pounds_per_foot = None
        
        self.__micrograms_per_millimeter = None
        
        self.__milligrams_per_millimeter = None
        
        self.__kilograms_per_millimeter = None
        
        self.__micrograms_per_centimeter = None
        
        self.__milligrams_per_centimeter = None
        
        self.__kilograms_per_centimeter = None
        
        self.__micrograms_per_meter = None
        
        self.__milligrams_per_meter = None
        
        self.__kilograms_per_meter = None
        

    def __convert_from_base(self, from_unit: LinearDensityUnits) -> float:
        value = self.__value
        
        if from_unit == LinearDensityUnits.GramPerMillimeter:
            return (value)
        
        if from_unit == LinearDensityUnits.GramPerCentimeter:
            return (value / 1e-1)
        
        if from_unit == LinearDensityUnits.GramPerMeter:
            return (value / 1e-3)
        
        if from_unit == LinearDensityUnits.PoundPerInch:
            return (value * 5.5997415e-2)
        
        if from_unit == LinearDensityUnits.PoundPerFoot:
            return (value / 1.48816394)
        
        if from_unit == LinearDensityUnits.MicrogramPerMillimeter:
            return ((value) / 1e-06)
        
        if from_unit == LinearDensityUnits.MilligramPerMillimeter:
            return ((value) / 0.001)
        
        if from_unit == LinearDensityUnits.KilogramPerMillimeter:
            return ((value) / 1000.0)
        
        if from_unit == LinearDensityUnits.MicrogramPerCentimeter:
            return ((value / 1e-1) / 1e-06)
        
        if from_unit == LinearDensityUnits.MilligramPerCentimeter:
            return ((value / 1e-1) / 0.001)
        
        if from_unit == LinearDensityUnits.KilogramPerCentimeter:
            return ((value / 1e-1) / 1000.0)
        
        if from_unit == LinearDensityUnits.MicrogramPerMeter:
            return ((value / 1e-3) / 1e-06)
        
        if from_unit == LinearDensityUnits.MilligramPerMeter:
            return ((value / 1e-3) / 0.001)
        
        if from_unit == LinearDensityUnits.KilogramPerMeter:
            return ((value / 1e-3) / 1000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: LinearDensityUnits) -> float:
        
        if to_unit == LinearDensityUnits.GramPerMillimeter:
            return (value)
        
        if to_unit == LinearDensityUnits.GramPerCentimeter:
            return (value * 1e-1)
        
        if to_unit == LinearDensityUnits.GramPerMeter:
            return (value * 1e-3)
        
        if to_unit == LinearDensityUnits.PoundPerInch:
            return (value / 5.5997415e-2)
        
        if to_unit == LinearDensityUnits.PoundPerFoot:
            return (value * 1.48816394)
        
        if to_unit == LinearDensityUnits.MicrogramPerMillimeter:
            return ((value) * 1e-06)
        
        if to_unit == LinearDensityUnits.MilligramPerMillimeter:
            return ((value) * 0.001)
        
        if to_unit == LinearDensityUnits.KilogramPerMillimeter:
            return ((value) * 1000.0)
        
        if to_unit == LinearDensityUnits.MicrogramPerCentimeter:
            return ((value * 1e-1) * 1e-06)
        
        if to_unit == LinearDensityUnits.MilligramPerCentimeter:
            return ((value * 1e-1) * 0.001)
        
        if to_unit == LinearDensityUnits.KilogramPerCentimeter:
            return ((value * 1e-1) * 1000.0)
        
        if to_unit == LinearDensityUnits.MicrogramPerMeter:
            return ((value * 1e-3) * 1e-06)
        
        if to_unit == LinearDensityUnits.MilligramPerMeter:
            return ((value * 1e-3) * 0.001)
        
        if to_unit == LinearDensityUnits.KilogramPerMeter:
            return ((value * 1e-3) * 1000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_grams_per_millimeter(grams_per_millimeter: float):
        """
        Create a new instance of LinearDensity from a value in grams_per_millimeter.

        

        :param meters: The LinearDensity value in grams_per_millimeter.
        :type grams_per_millimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(grams_per_millimeter, LinearDensityUnits.GramPerMillimeter)

    
    @staticmethod
    def from_grams_per_centimeter(grams_per_centimeter: float):
        """
        Create a new instance of LinearDensity from a value in grams_per_centimeter.

        

        :param meters: The LinearDensity value in grams_per_centimeter.
        :type grams_per_centimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(grams_per_centimeter, LinearDensityUnits.GramPerCentimeter)

    
    @staticmethod
    def from_grams_per_meter(grams_per_meter: float):
        """
        Create a new instance of LinearDensity from a value in grams_per_meter.

        

        :param meters: The LinearDensity value in grams_per_meter.
        :type grams_per_meter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(grams_per_meter, LinearDensityUnits.GramPerMeter)

    
    @staticmethod
    def from_pounds_per_inch(pounds_per_inch: float):
        """
        Create a new instance of LinearDensity from a value in pounds_per_inch.

        

        :param meters: The LinearDensity value in pounds_per_inch.
        :type pounds_per_inch: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(pounds_per_inch, LinearDensityUnits.PoundPerInch)

    
    @staticmethod
    def from_pounds_per_foot(pounds_per_foot: float):
        """
        Create a new instance of LinearDensity from a value in pounds_per_foot.

        

        :param meters: The LinearDensity value in pounds_per_foot.
        :type pounds_per_foot: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(pounds_per_foot, LinearDensityUnits.PoundPerFoot)

    
    @staticmethod
    def from_micrograms_per_millimeter(micrograms_per_millimeter: float):
        """
        Create a new instance of LinearDensity from a value in micrograms_per_millimeter.

        

        :param meters: The LinearDensity value in micrograms_per_millimeter.
        :type micrograms_per_millimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(micrograms_per_millimeter, LinearDensityUnits.MicrogramPerMillimeter)

    
    @staticmethod
    def from_milligrams_per_millimeter(milligrams_per_millimeter: float):
        """
        Create a new instance of LinearDensity from a value in milligrams_per_millimeter.

        

        :param meters: The LinearDensity value in milligrams_per_millimeter.
        :type milligrams_per_millimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(milligrams_per_millimeter, LinearDensityUnits.MilligramPerMillimeter)

    
    @staticmethod
    def from_kilograms_per_millimeter(kilograms_per_millimeter: float):
        """
        Create a new instance of LinearDensity from a value in kilograms_per_millimeter.

        

        :param meters: The LinearDensity value in kilograms_per_millimeter.
        :type kilograms_per_millimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(kilograms_per_millimeter, LinearDensityUnits.KilogramPerMillimeter)

    
    @staticmethod
    def from_micrograms_per_centimeter(micrograms_per_centimeter: float):
        """
        Create a new instance of LinearDensity from a value in micrograms_per_centimeter.

        

        :param meters: The LinearDensity value in micrograms_per_centimeter.
        :type micrograms_per_centimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(micrograms_per_centimeter, LinearDensityUnits.MicrogramPerCentimeter)

    
    @staticmethod
    def from_milligrams_per_centimeter(milligrams_per_centimeter: float):
        """
        Create a new instance of LinearDensity from a value in milligrams_per_centimeter.

        

        :param meters: The LinearDensity value in milligrams_per_centimeter.
        :type milligrams_per_centimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(milligrams_per_centimeter, LinearDensityUnits.MilligramPerCentimeter)

    
    @staticmethod
    def from_kilograms_per_centimeter(kilograms_per_centimeter: float):
        """
        Create a new instance of LinearDensity from a value in kilograms_per_centimeter.

        

        :param meters: The LinearDensity value in kilograms_per_centimeter.
        :type kilograms_per_centimeter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(kilograms_per_centimeter, LinearDensityUnits.KilogramPerCentimeter)

    
    @staticmethod
    def from_micrograms_per_meter(micrograms_per_meter: float):
        """
        Create a new instance of LinearDensity from a value in micrograms_per_meter.

        

        :param meters: The LinearDensity value in micrograms_per_meter.
        :type micrograms_per_meter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(micrograms_per_meter, LinearDensityUnits.MicrogramPerMeter)

    
    @staticmethod
    def from_milligrams_per_meter(milligrams_per_meter: float):
        """
        Create a new instance of LinearDensity from a value in milligrams_per_meter.

        

        :param meters: The LinearDensity value in milligrams_per_meter.
        :type milligrams_per_meter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(milligrams_per_meter, LinearDensityUnits.MilligramPerMeter)

    
    @staticmethod
    def from_kilograms_per_meter(kilograms_per_meter: float):
        """
        Create a new instance of LinearDensity from a value in kilograms_per_meter.

        

        :param meters: The LinearDensity value in kilograms_per_meter.
        :type kilograms_per_meter: float
        :return: A new instance of LinearDensity.
        :rtype: LinearDensity
        """
        return LinearDensity(kilograms_per_meter, LinearDensityUnits.KilogramPerMeter)

    
    @property
    def grams_per_millimeter(self) -> float:
        """
        
        """
        if self.__grams_per_millimeter != None:
            return self.__grams_per_millimeter
        self.__grams_per_millimeter = self.__convert_from_base(LinearDensityUnits.GramPerMillimeter)
        return self.__grams_per_millimeter

    
    @property
    def grams_per_centimeter(self) -> float:
        """
        
        """
        if self.__grams_per_centimeter != None:
            return self.__grams_per_centimeter
        self.__grams_per_centimeter = self.__convert_from_base(LinearDensityUnits.GramPerCentimeter)
        return self.__grams_per_centimeter

    
    @property
    def grams_per_meter(self) -> float:
        """
        
        """
        if self.__grams_per_meter != None:
            return self.__grams_per_meter
        self.__grams_per_meter = self.__convert_from_base(LinearDensityUnits.GramPerMeter)
        return self.__grams_per_meter

    
    @property
    def pounds_per_inch(self) -> float:
        """
        
        """
        if self.__pounds_per_inch != None:
            return self.__pounds_per_inch
        self.__pounds_per_inch = self.__convert_from_base(LinearDensityUnits.PoundPerInch)
        return self.__pounds_per_inch

    
    @property
    def pounds_per_foot(self) -> float:
        """
        
        """
        if self.__pounds_per_foot != None:
            return self.__pounds_per_foot
        self.__pounds_per_foot = self.__convert_from_base(LinearDensityUnits.PoundPerFoot)
        return self.__pounds_per_foot

    
    @property
    def micrograms_per_millimeter(self) -> float:
        """
        
        """
        if self.__micrograms_per_millimeter != None:
            return self.__micrograms_per_millimeter
        self.__micrograms_per_millimeter = self.__convert_from_base(LinearDensityUnits.MicrogramPerMillimeter)
        return self.__micrograms_per_millimeter

    
    @property
    def milligrams_per_millimeter(self) -> float:
        """
        
        """
        if self.__milligrams_per_millimeter != None:
            return self.__milligrams_per_millimeter
        self.__milligrams_per_millimeter = self.__convert_from_base(LinearDensityUnits.MilligramPerMillimeter)
        return self.__milligrams_per_millimeter

    
    @property
    def kilograms_per_millimeter(self) -> float:
        """
        
        """
        if self.__kilograms_per_millimeter != None:
            return self.__kilograms_per_millimeter
        self.__kilograms_per_millimeter = self.__convert_from_base(LinearDensityUnits.KilogramPerMillimeter)
        return self.__kilograms_per_millimeter

    
    @property
    def micrograms_per_centimeter(self) -> float:
        """
        
        """
        if self.__micrograms_per_centimeter != None:
            return self.__micrograms_per_centimeter
        self.__micrograms_per_centimeter = self.__convert_from_base(LinearDensityUnits.MicrogramPerCentimeter)
        return self.__micrograms_per_centimeter

    
    @property
    def milligrams_per_centimeter(self) -> float:
        """
        
        """
        if self.__milligrams_per_centimeter != None:
            return self.__milligrams_per_centimeter
        self.__milligrams_per_centimeter = self.__convert_from_base(LinearDensityUnits.MilligramPerCentimeter)
        return self.__milligrams_per_centimeter

    
    @property
    def kilograms_per_centimeter(self) -> float:
        """
        
        """
        if self.__kilograms_per_centimeter != None:
            return self.__kilograms_per_centimeter
        self.__kilograms_per_centimeter = self.__convert_from_base(LinearDensityUnits.KilogramPerCentimeter)
        return self.__kilograms_per_centimeter

    
    @property
    def micrograms_per_meter(self) -> float:
        """
        
        """
        if self.__micrograms_per_meter != None:
            return self.__micrograms_per_meter
        self.__micrograms_per_meter = self.__convert_from_base(LinearDensityUnits.MicrogramPerMeter)
        return self.__micrograms_per_meter

    
    @property
    def milligrams_per_meter(self) -> float:
        """
        
        """
        if self.__milligrams_per_meter != None:
            return self.__milligrams_per_meter
        self.__milligrams_per_meter = self.__convert_from_base(LinearDensityUnits.MilligramPerMeter)
        return self.__milligrams_per_meter

    
    @property
    def kilograms_per_meter(self) -> float:
        """
        
        """
        if self.__kilograms_per_meter != None:
            return self.__kilograms_per_meter
        self.__kilograms_per_meter = self.__convert_from_base(LinearDensityUnits.KilogramPerMeter)
        return self.__kilograms_per_meter

    
    def to_string(self, unit: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter) -> string:
        """
        Format the LinearDensity to string.
        Note! the default format for LinearDensity is KilogramPerMeter.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == LinearDensityUnits.GramPerMillimeter:
            return f"""{self.grams_per_millimeter} g/mm"""
        
        if unit == LinearDensityUnits.GramPerCentimeter:
            return f"""{self.grams_per_centimeter} g/cm"""
        
        if unit == LinearDensityUnits.GramPerMeter:
            return f"""{self.grams_per_meter} g/m"""
        
        if unit == LinearDensityUnits.PoundPerInch:
            return f"""{self.pounds_per_inch} lb/in"""
        
        if unit == LinearDensityUnits.PoundPerFoot:
            return f"""{self.pounds_per_foot} lb/ft"""
        
        if unit == LinearDensityUnits.MicrogramPerMillimeter:
            return f"""{self.micrograms_per_millimeter} """
        
        if unit == LinearDensityUnits.MilligramPerMillimeter:
            return f"""{self.milligrams_per_millimeter} """
        
        if unit == LinearDensityUnits.KilogramPerMillimeter:
            return f"""{self.kilograms_per_millimeter} """
        
        if unit == LinearDensityUnits.MicrogramPerCentimeter:
            return f"""{self.micrograms_per_centimeter} """
        
        if unit == LinearDensityUnits.MilligramPerCentimeter:
            return f"""{self.milligrams_per_centimeter} """
        
        if unit == LinearDensityUnits.KilogramPerCentimeter:
            return f"""{self.kilograms_per_centimeter} """
        
        if unit == LinearDensityUnits.MicrogramPerMeter:
            return f"""{self.micrograms_per_meter} """
        
        if unit == LinearDensityUnits.MilligramPerMeter:
            return f"""{self.milligrams_per_meter} """
        
        if unit == LinearDensityUnits.KilogramPerMeter:
            return f"""{self.kilograms_per_meter} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter) -> string:
        """
        Get LinearDensity unit abbreviation.
        Note! the default abbreviation for LinearDensity is KilogramPerMeter.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == LinearDensityUnits.GramPerMillimeter:
            return """g/mm"""
        
        if unit_abbreviation == LinearDensityUnits.GramPerCentimeter:
            return """g/cm"""
        
        if unit_abbreviation == LinearDensityUnits.GramPerMeter:
            return """g/m"""
        
        if unit_abbreviation == LinearDensityUnits.PoundPerInch:
            return """lb/in"""
        
        if unit_abbreviation == LinearDensityUnits.PoundPerFoot:
            return """lb/ft"""
        
        if unit_abbreviation == LinearDensityUnits.MicrogramPerMillimeter:
            return """"""
        
        if unit_abbreviation == LinearDensityUnits.MilligramPerMillimeter:
            return """"""
        
        if unit_abbreviation == LinearDensityUnits.KilogramPerMillimeter:
            return """"""
        
        if unit_abbreviation == LinearDensityUnits.MicrogramPerCentimeter:
            return """"""
        
        if unit_abbreviation == LinearDensityUnits.MilligramPerCentimeter:
            return """"""
        
        if unit_abbreviation == LinearDensityUnits.KilogramPerCentimeter:
            return """"""
        
        if unit_abbreviation == LinearDensityUnits.MicrogramPerMeter:
            return """"""
        
        if unit_abbreviation == LinearDensityUnits.MilligramPerMeter:
            return """"""
        
        if unit_abbreviation == LinearDensityUnits.KilogramPerMeter:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, LinearDensity):
            raise TypeError("unsupported operand type(s) for +: 'LinearDensity' and '{}'".format(type(other).__name__))
        return LinearDensity(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, LinearDensity):
            raise TypeError("unsupported operand type(s) for *: 'LinearDensity' and '{}'".format(type(other).__name__))
        return LinearDensity(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, LinearDensity):
            raise TypeError("unsupported operand type(s) for -: 'LinearDensity' and '{}'".format(type(other).__name__))
        return LinearDensity(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, LinearDensity):
            raise TypeError("unsupported operand type(s) for /: 'LinearDensity' and '{}'".format(type(other).__name__))
        return LinearDensity(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, LinearDensity):
            raise TypeError("unsupported operand type(s) for %: 'LinearDensity' and '{}'".format(type(other).__name__))
        return LinearDensity(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, LinearDensity):
            raise TypeError("unsupported operand type(s) for **: 'LinearDensity' and '{}'".format(type(other).__name__))
        return LinearDensity(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, LinearDensity):
            raise TypeError("unsupported operand type(s) for ==: 'LinearDensity' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, LinearDensity):
            raise TypeError("unsupported operand type(s) for <: 'LinearDensity' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, LinearDensity):
            raise TypeError("unsupported operand type(s) for >: 'LinearDensity' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, LinearDensity):
            raise TypeError("unsupported operand type(s) for <=: 'LinearDensity' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, LinearDensity):
            raise TypeError("unsupported operand type(s) for >=: 'LinearDensity' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value